UrlUtil class

Constructors

UrlUtil()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

compilePathToUri(Uri uri, Uri baseUri) → Uri
isUrlNeedToOveride(Uri? globalUrl, Uri url) → Uri
mapToQuery(Map<String, String> map, {Encoding? encoding}) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited