FetchHttpActivitiesParam class

Constructors

FetchHttpActivitiesParam({String? url, int? startDate, List<int?>? statusCodes, int? endDate})

Properties

endDate ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startDate ↔ int?
getter/setter pair
statusCodes ↔ List<int?>?
getter/setter pair
url ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited